/*
    Copyright (C) 2011 jeanfi@gmail.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301 USA
*/

#include <string.h>

#include "chart.h"
#include "html.h"
#include "lp_ws.h"
#include "ppastats.h"

#include <stdio.h>
#include <stdlib.h>

static char *get_path(const char *dir, const char *file)
{
	char *path = malloc(strlen(dir)+1+
			    strlen(file)+
			    strlen(".html")+
			    1);

	strcpy(path, dir);
	strcat(path, "/");
	strcat(path, file);
	strcat(path, ".html");

	return path;
}

static void
packages_to_html(struct package_stats **packages,
		 const char *dir)
{
	struct package_stats **cur;
	struct package_stats *p;
	char *path;

	cur = packages;
	while (*cur) {
		p = *cur;

		path = get_path(dir, p->name);
		generate_chart(path, p->name, p->name,
			       p->daily_download_totals);
		free(path);

		cur++;
	}
}

void
ppa_to_html(const char *owner,
	    const char *ppa,
	    const char *package_status,
	    const char *output_dir)
{
	char *path;
	struct ppa_stats *ppastats;
	struct daily_download_total **totals;

	ppastats = create_ppa_stats(owner, ppa, package_status);
	totals = ppastats->daily_download_totals;

	path = get_path(output_dir, "ppa");
	generate_chart(path, "PPA Statistics", ppa, totals);
	free(path);

	packages_to_html(ppastats->packages, output_dir);

	ppa_stats_free(ppastats);
}
